==> haskell-blaze-markup-0.8.2.8-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-markup
version:              0.8.2.8
visibility:           public
id:                   blaze-markup-0.8.2.8-4VB51SV8RIBLsZP8H8ryPV
key:                  blaze-markup-0.8.2.8-4VB51SV8RIBLsZP8H8ryPV
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier, Deepak Jois
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  548d7b77c68c016349537b1c1f091e5a
exposed:              True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8

import-dirs:          /usr/lib/ghc-8.10.4/site-local/blaze-markup-0.8.2.8
library-dirs:         /usr/lib/ghc-8.10.4/site-local/blaze-markup-0.8.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/blaze-markup-0.8.2.8
hs-libraries:         HSblaze-markup-0.8.2.8-4VB51SV8RIBLsZP8H8ryPV
depends:
    base-4.14.1.0 blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ
    bytestring-0.10.12.0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock

haddock-html:         /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-markup-0.8.2.8-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-markup
version:              0.8.2.8
visibility:           public
id:                   blaze-markup-0.8.2.8-BqQXTPAKmSh8XDrKlZRb34
key:                  blaze-markup-0.8.2.8-BqQXTPAKmSh8XDrKlZRb34
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier, Deepak Jois
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  e24ca8050da2826d89a00e4e0b3c2853
exposed:              True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8

import-dirs:          /usr/lib/ghc-8.10.4/site-local/blaze-markup-0.8.2.8
library-dirs:         /usr/lib/ghc-8.10.4/site-local/blaze-markup-0.8.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/blaze-markup-0.8.2.8
hs-libraries:         HSblaze-markup-0.8.2.8-BqQXTPAKmSh8XDrKlZRb34
depends:
    base-4.14.1.0 blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ
    bytestring-0.10.12.0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock

haddock-html:         /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
